function [spot,Xlocff,Ylocff] = failureSurface(h,BM,RV,society)
    %%% divide BM by section modulus s gives us stress
    %%% divide stress by yield stress to put us on failure surface
    %%% only consider when BM is negative (compressive) but make positive for
    %%% plotting purposes

    beta = 4*pi/180; 
    Eyoung = 190*10^9;
    
    [a,Hw,Tf,bf,Tp,~,~,At,sigmaYBar,Yc,Yf,Im4,~,~,Im4Tr,MP,midshipSecMod] = getDim(society);

    sigmaA = BM/midshipSecMod;
    
    y = (Hw+Tp+Tf)-Yc-Tf/2;
    sigmaE = pi^2*Eyoung*Im4/(At*a^2);
    phi = 1./(1-sigmaA./sigmaE);
    sigmaF = sigmaA.*(1+(At*a/750*y.*phi)/Im4);
    sigmaBySigmaY = sigmaF/sigmaYBar;
  

    %%% find instances when RM changes sign from + to - (meaning ship is
    %%% impacting water surface) then do const*RV^2 during that period and let
    %%% pressure be zero during other points (i.e. no impact pressure)
    %%% periods where we consider pressure is when RV<0
    %%% make times when RV >0 to equal zero

    rho = 1000; %kg/m3
    Im3 = Im4/bf; % m3 for correct Faltinsen unit
    NDstrain = 0.19;
    strain = NDstrain*Yc*RV.^2*rho*a^2/(Eyoung*Im3*tan(beta));

    sigma = strain*Eyoung; %Pa
    M0divMP = (sigma*Im4Tr/Yf)/MP;

    %%% get failure surface for each CS
    [ptX,ptY,m2] = hughes(society);

    %%% no failure when (BM,M0) is less than both curves
    y1 = @(x1) 1-(1-ptY)/ptX*x1;
    y2 = @(x2) (ptY-m2*ptX) + m2*x2;

    check = zeros(length(sigmaBySigmaY),2);
    y1check = y1(sigmaBySigmaY);
    y2check = y2(sigmaBySigmaY);

    anotherCheck = sigmaBySigmaY >= 0;
    check(:,1) = (M0divMP >= y1check) .* anotherCheck;
    check(:,2) = (M0divMP > y2check) .* anotherCheck;       

    A = find(check(:,1));
    B = find(check(:,2));
    C = [A;B]; %%% locations of failure in time series
    
    %%% to plot limit surface
%     x1 = linspace(0,ptX,1000);
%     x2 = linspace(ptX,1,1000);
%     y1 = 1-(1-ptY)/ptX*x1;
%     y2 = (ptY-m2*ptX) + m2*x2;
%     xx = [x1 x2];
%     yy = [y1 y2];
%     plot(xx,yy,'-k','LineWidth',1.5)
%     axis([0 1 0 1.1])

    if length(C) >= 1
        firstLocation = min(C);
        spot = h;
        Xlocff = sigmaBySigmaY(firstLocation);
        Ylocff = M0divMP(firstLocation);
    else
        spot = 0;
        Ylocff = 0;
        Xlocff = 0;
    end    
end


