function failureSurface = findSSandSP(MphiRV,MphiBM,wo)
[HsTzTable, HsRange, TzRange] = waveParameterDist;

tic % timing 
d_omega = wo(2)-wo(1);
U = 10.2889; % m/s (20 knots service speed)

societies = [2 1 3];
for societyIN = 1:3
    society = societies(societyIN);
    fieldName = strcat('CS',num2str(society));
    
    %%% use more points so we get closest to Mo/Mp = 1
    %%% more points can be added, which leads to a more 'accurate' limit
    %%% surface, but results in a longer computation time
    RV = linspace(0,12,35);
    BM = linspace(0,15e8,35);
 
    [M,SY] = failureSurf(society,BM,RV);
    xLookupFull = [BM' SY'];
    yLookup = [RV' M'];
    yLookup = yLookup(1:find(M>1,1),:);   
    xLookup = zeros(size(yLookup));
    
    %%% now find X val that leads to failure given Y values
    [ptX,ptY,m2] = hughes(society); % get failure surface
    x1loc = @(y1) (1-y1)*ptX/(1-ptY);
    x2loc = @(y2) (y2+m2*ptX-ptY)/m2;
    
    for j = 1:length(yLookup)
        M0Mp = yLookup(j,2);
        
        if M0Mp < ptY
            ssY = x2loc(M0Mp);
        else 
            ssY = x1loc(M0Mp);
        end
        
        if M0Mp >= 1
            xLookup(j,1) = 0;
            xLookup(j,2) = 0;
        else
            ssYless = find(xLookupFull(:,2)<= ssY, 1, 'last' );
            ssYmore = find(xLookupFull(:,2)>= ssY, 1, 'first' );
            BMless = xLookupFull(ssYless,1);
            BMmore = xLookupFull(ssYmore,1);

            BMlin = linspace(BMless,BMmore,100);
            [~,SYlin] = failureSurf(society,BMlin,0);
            [~,location] = min(abs(SYlin-ssY));
            xLookup(j,1) = BMlin(location);
            xLookup(j,2) = ssY;
        end
    end
    
    %%% make sure maximum y-value is 1
    failureSurface.(fieldName).('x') = xLookup;
    failureSurface.(fieldName).('y') = yLookup;
    failureSurface.(strcat('CS',num2str(society))).('failProbTab') = zeros(size(HsTzTable));
end
names = fieldnames(failureSurface);

count = 1;

for h = 1:length(HsRange)    
    for t = 1:length(TzRange)
        if HsTzTable(h,t) > 1.1416e-06 %3.0 hour exposure minimum          
            
            %%% total 300 year expsosure (30-year lifetiime with PNE = 0.990)
            %%% find hours in give sea state based on wave parameter model
            hours = 300*365.25*24*HsTzTable(h,t);    
            
            wz = 2*pi./TzRange(t);
            IStz = HsRange(h).^2/(4*pi).*wz.^4./wo.^5.*exp(-1/pi*(wz./wo).^4);
            IStz(1) = 0;
            InputSpectrum = [wo IStz];

            SpecOutRV = (MphiRV(:,1).^2).*(IStz);
            aRV = sqrt(2*SpecOutRV*d_omega);
            rmsRV = sqrt(1/2*sum(aRV.^2));
            
            SpecOutBM = (MphiBM(:,1).^2).*(IStz);
            aBM = sqrt(2*SpecOutBM*d_omega);
            rmsBM = sqrt(1/2*sum(aBM.^2));
            
            for societyIN = 1:3
                numSP = length(failureSurface.(names{societyIN}).x);
                maxRatio = 0; 
                
                HsHOLD = 0; TzHOLD = 0; hoursHOLD = 0;  
                alphaRVHOLD = 0; betaBMHOLD = 0; maxRatioHOLD = 0; 
                
                maxTEVsigmaRV = max(failureSurface.(names{societyIN}).y(:,1));
                maxTEVsigmaBM = max(failureSurface.(names{societyIN}).x(:,1));                                    
                                     
                for p = 1:numSP
                    %%% make MphiSP1 based on rms of BM and RV
                    alphaRV = failureSurface.(names{societyIN}).y(p,1)/maxTEVsigmaRV;
                    betaBM  = failureSurface.(names{societyIN}).x(p,1)/maxTEVsigmaBM;
                    
                    z = alphaRV*MphiRV(:,1)/rmsRV.*exp(1i.*MphiRV(:,2)*pi/180) + betaBM*MphiBM(:,1)/rmsBM.*exp(1i.*MphiBM(:,2)*pi/180);
                    M = abs(z);
                    phiInside = angle(z)*180/pi; %phase should be in degrees going into DLG
                    MphiSP1 = [M phiInside];

                    SpecOutSP1 = (MphiSP1(:,1).^2).*(IStz);
                    aSP1 = sqrt(2*SpecOutSP1*d_omega);
                    rmsSP1 = sqrt(1/2*sum(aSP1.^2));
                    
                    TEVzSP1 = normalizedSpectra(InputSpectrum,MphiSP1,hours,U);
                    
                    if isreal(TEVzSP1) == 0
                        TEVzSP1 = 0;
                    end
                   
                    %%% get SP value at point on failure surface
                    gSP = (alphaRV*failureSurface.(names{societyIN}).y(p,1)/rmsRV + betaBM*failureSurface.(names{societyIN}).x(p,1)/rmsBM)/rmsSP1;
                    ynSP = linspace(0,7,2000);
                    nSP = TEVtoNumberOfSamples(TEVzSP1);
                    gTEVSP = nSP*pdf('Normal',ynSP,0,1).*(cdf('Normal',ynSP,0,1)).^(nSP-1);
                    
                    integrateTo = find(ynSP<gSP, 1, 'last' );
                    if integrateTo <= 1
                        ratio = 0;
                        failureSurface.(names{societyIN}).('SPinfo')(count,1) = HsRange(h);
                        failureSurface.(names{societyIN}).('SPinfo')(count,2) = TzRange(t);
                        failureSurface.(names{societyIN}).('SPinfo')(count,3) = hours;                    
                        failureSurface.(names{societyIN}).('SPinfo')(count,4) = alphaRV;                   
                        failureSurface.(names{societyIN}).('SPinfo')(count,5) = betaBM;
                        failureSurface.(names{societyIN}).('SPinfo')(count,6) = ratio; 
                    else
                        ratio = 1-trapz(ynSP(1:integrateTo),gTEVSP(1:integrateTo)); %%% solving for alpha here
                        failureSurface.(names{societyIN}).('SPinfo')(count,1) = HsRange(h);
                        failureSurface.(names{societyIN}).('SPinfo')(count,2) = TzRange(t);
                        failureSurface.(names{societyIN}).('SPinfo')(count,3) = hours;                    
                        failureSurface.(names{societyIN}).('SPinfo')(count,4) = alphaRV;                   
                        failureSurface.(names{societyIN}).('SPinfo')(count,5) = betaBM;
                        failureSurface.(names{societyIN}).('SPinfo')(count,6) = ratio;    
                    end
                    
                    if ratio > maxRatio
                        maxRatio = ratio;
                        failureSurface.(names{societyIN}).('failProbTab')(h,t) = maxRatio;  
                        HsHOLD = HsRange(h);
                        TzHOLD = TzRange(t);
                        hoursHOLD = hours;
                        alphaRVHOLD = alphaRV;
                        betaBMHOLD = betaBM;
                        maxRatioHOLD = maxRatio;
                    end
                    
                    count = count+1;
                end

                failureSurface.(names{societyIN}).('failProbTab')(h,t) = maxRatioHOLD;                        
                failureSurface.(names{societyIN}).('failProbInfo')(count,1) = HsHOLD;
                failureSurface.(names{societyIN}).('failProbInfo')(count,2) = TzHOLD;  
                failureSurface.(names{societyIN}).('failProbInfo')(count,3) = hoursHOLD; 
                failureSurface.(names{societyIN}).('failProbInfo')(count,4) = alphaRVHOLD; 
                failureSurface.(names{societyIN}).('failProbInfo')(count,5) = betaBMHOLD; 
                failureSurface.(names{societyIN}).('failProbInfo')(count,6) = maxRatioHOLD; 
            end
        else
            % do nothing
        end
        count = count+1;      
    end  
    count = count+1;
end

for g = 1:3
    failureSurface.(names{g}).('failProbInfo')(all(failureSurface.(names{g}).('failProbInfo')==0,2),:)=[];
    failureSurface.(names{g}).('SPinfo')(all(failureSurface.(names{g}).('SPinfo')==0,2),:)=[];
end

toc % timing 
%%
    function TEVzSP = normalizedSpectra(InputSpectrum,MphiSP1,hours,U)
        %%% note we transform our input spectrum and transfer functions to
        %%% the ship coordinate space
        heading = 180; %head seas in degrees

        %%% Set parameters for Monte Carlo simulation
        woShipmo = InputSpectrum(:,1);
        weShipmo = woShipmo-U*woShipmo.^2/9.81*cos(heading);
        InputSpectrumWo = InputSpectrum(:,2);

        %%% Get response spectra of BM and RV in earth coordinate
        SPspecWo = InputSpectrumWo.*(MphiSP1(:,1)).^2;

        %%% Transform Shipmo wo coordinate and response spectra of BM and RV in the
        %%% wo space to encounter freuency space
        SPspecWe = wo2we(SPspecWo,woShipmo,U,heading);

            function output = wo2we(input,wo,U,heading)
                output = input./(1-2*U*wo/9.81*cos(heading));
            end

        m2SP = trapz(weShipmo,SPspecWe.*weShipmo.^2);
        m0SP = trapz(weShipmo,SPspecWe);

        %%% zero-crossing period
        TzSP = 2*pi*sqrt(m0SP/m2SP);
        TEVzSP = sqrt(2*log(hours*3600/TzSP));
    end

    function [M0divMP, sigmaBySigmaY] = failureSurf(society,BM,RV)
        %%% divide BM by section modulus s gives us stress
        %%% divide stress by yield stress to put us on failure surface
        %%% only consider when BM is negative (compressive) but make positive for
        %%% plotting purposes

        beta = 4*pi/180; 
        Eyoung = 190*10^9;
        
        [a,Hw,Tf,bf,Tp,~,~,At,sigmaYBar,Yc,Yf,Im4,~,~,Im4Tr,MP,midshipSecMod] = getDim(society);
        sigmaA = BM/midshipSecMod; % bottom cross-section modulus
        
        y = (Hw+Tp+Tf)-Yc-Tf/2;
        sigmaE = pi^2*Eyoung*Im4/(At*a^2);
        phi = 1./(1-sigmaA./sigmaE);
        sigmaF = sigmaA.*(1+(At*a/750*y.*phi)/Im4);
        sigmaBySigmaY = sigmaF/sigmaYBar;

        %%% find instances when RM changes sign from + to - (meaning ship is
        %%% impacting water surface) then do const*RV^2 during that period and let
        %%% pressure be zero during other points (i.e. no impact pressure)
        %%% periods where we consider pressure is when RV<0
        %%% make times when RV >0 to equal zero
    
        rho = 1000; %kg/m3
        Im3 = Im4/bf; % m3 for correct Faltinsen unit
        NDstrain = 0.19;
        strain = NDstrain*Yc*RV.^2*rho*a^2/(Eyoung*Im3*tan(beta));
        
        sigma = strain*Eyoung; %Pa
        M0divMP = (sigma*Im4Tr/Yf)/MP;    
    end


    function [f,Hs,Tp] = waveParameterDist
        %%% North Sea
        alpha = 2.846;
        betaIN = 1.471;
        gamma = 2.393; %remember Hs must be greater than gamma

        a1 = 0.1;
        a2 = 1.489;
        a3 = 0.1901;
        b1 = 0.04;
        b2 = 0.1748;
        b3 = -0.2243;

        Hs = 2.5:0.25:11.5;%column
        Tp = 1.5:0.25:12.5;%row

        Hs = Hs';

        dH = (Hs(2)-Hs(1));
        dT = (Tp(2)-Tp(1));

        [TpR,HsR] = meshgrid(Tp',Hs');

        mu = a1+a2.*HsR.^a3;
        sigma = b1+b2.*exp(b3*HsR);

        %%% alternative to fth distribution, just use lognormal
        % fth = 1./(sigma.*TpR*sqrt(2*pi)).*exp(-(log(TpR)-mu).^2./(2*sigma.^2));
        fth = lognpdf(TpR,mu,sigma)*dT;

        %%% alternative to fh definition, just use weibull pdf
        % fh = beta/alpha*x.^(beta-1).*exp(-x.^beta);
        fh = wblpdf(Hs-gamma,alpha,betaIN).*dH;

        f = fth.*fh;

        %%% basically already correctly normalized, except for fact that our Hs and
        %%% Tx range don't cover full range for perfect pdf normalization
        %%% a = 1.0071 ok
        a = sum(f(:));
        f = f./a;
    end

end

