    function [a,Hw,Tf,bf,Tp,sigmaYS,sigmaYP,At,sigmaYBar,Yc,Yf,Im4,T,Atr,Im4Tr,MP,midshipSecMod,output] = getDim(society)
        % matrix of dimensions based on whatever class society panel is
        % specified

        %row is class society number
        %columns: panel length a, web height, web t, flange width, flange
        %t, stiffener spacing, plate t, yeild stress plate, yield stress
        %stiffener, sigmaYbar
        
        Eyoung = 190*10^9;
        sigmaY = 3.30e8;
        
        dimensions = [1.905 0.1600  0.0062  0.1200 0.0098  0.6720 0.00900 sigmaY sigmaY 3.77;... %CS1
                      1.905 0.1500  0.0090  0.0900 0.0140  0.7000 0.01100 sigmaY sigmaY 4.60;... %CS2
                      1.905 0.1544  0.0060  0.1018 0.0089  0.5000 0.00810 sigmaY sigmaY 4.14;... %CS3
                      1.905 0.11364 0.00635 0.0630 0.01336 0.3640 0.00700 sigmaY sigmaY 3.64;... %CS4
                      1.905 0.2469  0.0058  0.1016 0.0069  0.6000 0.00800 sigmaY sigmaY 3.34;... %CS5
                      1.905 0.2200  0.0060  0.2000 0.0060  0.4000 0.01000 sigmaY sigmaY 4.93;... %CS6
                      1.905 0.2540  0.0062  0.1016 0.0098  0.4018 0.00715 sigmaY sigmaY 3.34;... %Scantling
                      1.905 0.1520  0.0073  0.0286 0.0159  0.5330 0.00970 324e6 385e6   3.34];...%panel A5  
  

        a  = dimensions(society,1); %panel length m    
        Hw = dimensions(society,2); %web height m
        Tw = dimensions(society,3); %web thickness m
        Hf = dimensions(society,4); %flange length m
        Tf = dimensions(society,5); %flange thickness m
        bf = dimensions(society,6); %stiffener spacing m
        Tp = dimensions(society,7); %plate thickness m
        sigmaYP = dimensions(society,8); %yield stress plate 
        sigmaYS = dimensions(society,9); %yield stress stiffener
        midshipSecMod = dimensions(society,10); % midship section modulus
                          
        Aw = Hw*Tw; %web area m^2
        Af = Hf*Tf; %flange area m^2
        Ap = bf*Tp; %plate area m^2
        At = Aw + Af + Ap; %total area m^2

        %%% Mean yield stress over entire section Hughes 14.1.1
        sigmaYBar = (sigmaYS*(Af+Aw)+sigmaYP*Ap)/At;

        %%% moment of area about bottom edge of cross-section
        Ma = bf*Tp*(Tp/2) + Hw*Tw*(Tp+Hw/2) + Hf*Tf*(Tp+Hw+Tf/2); 

        %%% location of neutral axis
        Yc = Ma/At;

        %%% Distance from centroidal axis to midthickness of stiffener, by
        %%% sign convention negative
        Yf = Hw+Tf+Tp-Tf/2-Yc;

        %%% moment of inertia about neutral axis
        Im4 = 1/12*Hf*Tf^3 + Af*(Tp+Hw+Tf/2-Yc)^2 + ...
            1/12*Tw*Hw^3 + Aw*(Tp+Hw/2-Yc)^2 + ...
            1/12*bf*Tp^3 + Ap*(Tp/2-Yc)^2;

        %%% Calculate Secant Modulus for transformed stiffener properties
        slendernessParameter = bf/Tp*sqrt(sigmaYBar/Eyoung); % Hughes 9.3.1
        zetaSlender = 1+2.75/slendernessParameter^2; % Hughes 12.6.4
        T = 0.25*(2+zetaSlender-sqrt(zetaSlender^2-10.4/slendernessParameter^2));

        %%% Get transformed properties from T;
        HfTr = Hf*T;
        Atr = Hw*Tw + HfTr*Tf + bf*Tp;

        Im4Tr = 1/12*HfTr*Tf^3 + HfTr*Tf*(Tp+Hw+Tf/2-Yc)^2 + ...
            1/12*Tw*Hw^3 + Aw*(Tp+Hw/2-Yc)^2 + ...
            1/12*bf*Tp^3 + Ap*(Tp/2-Yc)^2;

        %%% calculate plastic hinge moment
        C1 = (bf*Tp-Hw*Tw-Hf*Tf)/(2*bf*Tp);
        C2 = C1^2-C1+0.5;
        gg = C1*Tp;
        Zf = Hf*Tf*(Hw+gg+0.5*Tf);
        Zw = Hw*Tw*(0.5*Hw+gg);
        Zp = bf*Tp*Tp*C2;

        ZP = Zf+Zw+Zp;
        MP = sigmaYBar*ZP; %Hughes 16.1.2
        
        output = [sigmaYBar C1 C2 gg Zf Zw Zp ZP MP]';
   end 