    function [ptX,ptY,m2] = hughes(society)
        %%% calculate hughes failure diagram by going through mode 2-3 failure
        Eyoung = 190*10^9; %Young's modulus Pa
        sigmaY = 3.30e8;
            
        %%% run detDim to get dimensions & properties based on class society 
        [a,Hw,Tf,~,Tp,sigmaYS,sigmaYP,At,sigmaYBar,Yc,~,Im4,T,Atr,Im4Tr,MP,~] = getDim(society);
        M0divMp = 0.001:0.001:1;
        
        %%% Mode II Collapse
        M0 = M0divMp*MP;
        rhoTr = sqrt(Im4Tr/Atr);
        delta0 = 40*M0*a^2/(384*Eyoung*Im4);
        sigmaF = (T-0.1)/T*sigmaYP;
        mu =  M0*Yc./(Im4Tr*sigmaF);
        mu(1,1) = 0;
        eta = (a/750+delta0)*Yc/rhoTr^2;
        lambda = a/(pi*rhoTr)*sqrt(sigmaF/Eyoung);
        zetaII = (1-mu)+(1+eta)./lambda.^2;
        RII =  real(zetaII/2-sqrt(zetaII.^2/4-(1-mu)./lambda.^2));

        %%% Mode III Collapse        
        yF = (Hw+Tp+Tf)-Yc-Tf/2;
        etaGH = -1*(a/750+delta0)*yF/rhoTr^2;
        muGH =  M0*yF./(Im4Tr*sigmaYS);
        muGH(1,1) = 0;
        lambdaGH = a/(pi*rhoTr)*sqrt(sigmaYS/Eyoung);
        zetaGH = (1-muGH)-(1+etaGH)./lambdaGH.^2;
        RGH = zetaGH/2 + sqrt(zetaGH.^2/4+(1-muGH)./lambdaGH.^2);

        %%% solve for intersection point of lines for iteration
        x1 = RII.*sigmaF/sigmaYBar;
        x2 = -RGH.*sigmaYS/sigmaYBar;
        [~,loc] = min(abs(x1-x2));
        
        xINTmodes = x1(loc);
        yINTmodes = M0divMp(loc);

        %%% Hughes eq. 14.2.22b & 14.2.30
        mode2 = RII.*sigmaF/sigmaY*Atr/At;
        mode3 = (MP-M0)./(MP-yINTmodes*MP).*xINTmodes;
        
        %%% intersection point of final collapse mode lines
        [~,loc] = min(abs(mode2-mode3)); 

        %%% intersection point of mode 2 & 3 collapse from hughes
        xINT = mode2(loc);
        yINT = M0divMp(loc);
        ptF = mode2(1);
        
        ptX = xINT;
        ptY = yINT;
        m2 = ptY/(ptX-ptF);     
    end


